Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread troy d. straszheim

David Wolfe wrote:


This is my first attempt to use git, so I have no idea what this means.
Did that branch disappear or something?



Sorry about that.  Docs fixed.

-t

___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread David Wolfe

git clone git://sodium.resophonic.com/boost_cookbook
cd boost_cookbook
checkout -b my_doctweaks_branch boost_cmake_docs
emacs source/*.rst


When I try this on Windows, I get:

--
c:\opt>git clone sodium.resophonic.com/boost_cookbook
fatal: Could not switch to 'sodium.resophonic.com'

c:\opt>git clone git://sodium.resophonic.com/boost_cookbook
Initialized empty Git repository in c:/opt/boost_cookbook/.git/
remote: Counting objects: 161, done.
  
c:\opt>cd boost_cookbook

c:\opt\boost_cookbook>git checkout -b my_docs_branch boost_make_docs
fatal: git checkout: updating paths is incompatible with switching
branches.  Did you intend to checkout 'boost_make_docs' which can not be
resolved as commit?
--

This is my first attempt to use git, so I have no idea what this means.
Did that branch disappear or something?


- Dave Wolfe
  Fifth Sally Software LLC
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread Doug Gregor
On Wed, May 13, 2009 at 5:37 AM, Beman Dawes  wrote:
> On Tue, May 12, 2009 at 5:11 PM, Brad King  wrote:
>> Beman Dawes wrote:
>>>
>>> On Tue, May 12, 2009 at 4:38 PM, Doug Gregor 
>>> wrote:
>>>
 Beman, did you enable testing?
>>>
>>> No. I figured that was a bit much for now.
>>>
 Even without all of the tests, Boost still has a huge number of targets
 in it.
>>>
>>> Yes, although I've been impressed with how fast everything except the
>>> VS IDE load has been running.
>>
>> I'm surprised it takes so long without testing.  How many targets is it,
>> and how long is "long"?
>
> Sorry, I think my post was misleading. My tests with the VC++ IDE had
> BUILD_TESTING  turned on.

Ah, that explains it. With BUILD_TESTING off, you should be able to
load the Boost project into the VC++ IDE without much delay. By
consolidating library tests into a small number of executables (rather
than, *ahem*, Serialization's 400+ executable tests), we should
eliminate this bottleneck with the VC++ IDE *and* save a lot of time
and space when building/running Boost's regression tests.

> Could we change the name of that to BUILD_REGRESSION_TESTS, and change
> the tool tip to "Enable regression testing"?

Okay, done!

> If someone does that, could they please post the changeset or revision
> number so I can look at what it takes to make that kind of minor
> change.

The patch is below; I applied it in tools/build/CMake.

  - Doug

Index: BoostTesting.cmake
===
--- BoostTesting.cmake  (revision 52965)
+++ BoostTesting.cmake  (working copy)
@@ -37,10 +37,11 @@
 # want or need to perform regression testing on Boost. The Boost build
 # is significantly faster when we aren't also building regression
 # tests.
-option(BUILD_TESTING "Enable testing" OFF)
+option(BUILD_REGRESSION_TESTS "Enable regression testing" OFF)

-if (BUILD_TESTING)
+if (BUILD_REGRESSION_TESTS)
   enable_testing()
+  mark_as_advanced(BUILD_TESTING)

   option(TEST_INSTALLED_TREE "Enable testing of an already-installed tree" OFF)

@@ -50,7 +51,7 @@
   if (TEST_INSTALLED_TREE)
 
include("${CMAKE_INSTALL_PREFIX}/lib/Boost${BOOST_VERSION}/boost-targets.cmake")
   endif (TEST_INSTALLED_TREE)
-endif (BUILD_TESTING)
+endif (BUILD_REGRESSION_TESTS)

 
#---
 # This macro adds additional include directories based on the dependencies of
@@ -203,9 +204,9 @@
   set(BOOST_TEST_TESTNAME "${PROJECT_NAME}-${testname}")
   #message("testname: ${BOOST_TEST_TESTNAME}")
   # If testing is turned off, this test is not okay
-  if (NOT BUILD_TESTING)
+  if (NOT BUILD_REGRESSION_TESTS)
 set(BOOST_TEST_OKAY FALSE)
-  endif(NOT BUILD_TESTING)
+  endif(NOT BUILD_REGRESSION_TESTS)

 endmacro(boost_test_parse_args)

Index: BoostCore.cmake
===
--- BoostCore.cmake (revision 52965)
+++ BoostCore.cmake (working copy)
@@ -56,7 +56,7 @@
 # therefore, will build and install the library binary.
 #
 # For libraries that have regression tests, and when testing is
 # enabled globally by the BUILD_TESTING option, this macro also
 # defines the TEST_BOOST_LIBNAME option (defaults to ON). When ON, the
 # generated makefiles/project files will contain regression tests for
 # this library.
@@ -313,7 +313,7 @@
   endforeach(SUBDIR ${THIS_PROJECT_SRCDIRS})
 endif()

-if(BUILD_TESTING AND THIS_PROJECT_TESTDIRS)
+if(BUILD_REGRESSION_TESTS AND THIS_PROJECT_TESTDIRS)
   # Testing is enabled globally and this project has some
   # tests. Check whether we should include these tests.
   if (BOOST_TEST_LIBRARIES)
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread Doug Gregor
On Wed, May 13, 2009 at 6:33 AM, Beman Dawes  wrote:
> On Wed, May 13, 2009 at 12:02 AM, Doug Gregor  wrote:
>> Thanks! I committed some changes to the release branch that will, I
>> think, work around this problem. It looks like "foreach" is a special
>> variable in NSIS, and we have a library named "foreach", which appears
>> to have caused the failure. Of course, I can't test it on my Mac :)
>
> OK, it is working now!
>
> I'll start a new thread with more details.

Great news! Thanks, Beman.

  - Doug
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread Beman Dawes
On Wed, May 13, 2009 at 12:02 AM, Doug Gregor  wrote:
> Thanks! I committed some changes to the release branch that will, I
> think, work around this problem. It looks like "foreach" is a special
> variable in NSIS, and we have a library named "foreach", which appears
> to have caused the failure. Of course, I can't test it on my Mac :)

OK, it is working now!

I'll start a new thread with more details.

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-13 Thread Beman Dawes
On Tue, May 12, 2009 at 5:11 PM, Brad King  wrote:
> Beman Dawes wrote:
>>
>> On Tue, May 12, 2009 at 4:38 PM, Doug Gregor 
>> wrote:
>>
>>> Beman, did you enable testing?
>>
>> No. I figured that was a bit much for now.
>>
>>> Even without all of the tests, Boost still has a huge number of targets
>>> in it.
>>
>> Yes, although I've been impressed with how fast everything except the
>> VS IDE load has been running.
>
> I'm surprised it takes so long without testing.  How many targets is it,
> and how long is "long"?

Sorry, I think my post was misleading. My tests with the VC++ IDE had
BUILD_TESTING  turned on.

Could we change the name of that to BUILD_REGRESSION_TESTS, and change
the tool tip to "Enable regression testing"?

If someone does that, could they please post the changeset or revision
number so I can look at what it takes to make that kind of minor
change.

Thanks,

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Doug Gregor
On Tue, May 12, 2009 at 1:49 PM, Beman Dawes  wrote:
> On Tue, May 12, 2009 at 4:39 PM, Bill Hoffman  
> wrote:
>> Beman Dawes wrote:
>>
>>> Please check
>>> C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
>>> for errors
>>> CPack Error: Problem compressing the directory
>>> CPack Error: Error when generating package: Boost
>>> NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
>>> 2.6\bin\cpack.exe"' : return code '0x1'
>>> Stop.
>>>
>>> One clue might be that the CMake setup shows the UNZIP value as
>>> "C:/bgd/util/unzip.exe" That's almost certainly not the unzip program
>>> CMake expects. Perhaps I need to install cygwin zip/unzip programs?
>>> I'll see if they've got anything by that name.
>>>
>> I don't think zip should affect nsis.
>>
>>
>> What is in here:
>> C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
>
> I zipped up the log together with project.nsi and one other file.
>
> See http://mysite.verizon.net/beman/NSIS.zip

Thanks! I committed some changes to the release branch that will, I
think, work around this problem. It looks like "foreach" is a special
variable in NSIS, and we have a library named "foreach", which appears
to have caused the failure. Of course, I can't test it on my Mac :)

  - Doug
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Brad King

Beman Dawes wrote:

On Tue, May 12, 2009 at 4:38 PM, Doug Gregor  wrote:


Beman, did you enable testing?


No. I figured that was a bit much for now.


Even without all of the tests, Boost still has a huge number of targets in it.


Yes, although I've been impressed with how fast everything except the
VS IDE load has been running.


I'm surprised it takes so long without testing.  How many targets is it,
and how long is "long"?

-Brad

___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Beman Dawes
On Tue, May 12, 2009 at 4:38 PM, Doug Gregor  wrote:

> Beman, did you enable testing?

No. I figured that was a bit much for now.

> Even without all of the tests, Boost still has a huge number of targets in it.

Yes, although I've been impressed with how fast everything except the
VS IDE load has been running.

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Beman Dawes
On Tue, May 12, 2009 at 4:39 PM, Bill Hoffman  wrote:
> Beman Dawes wrote:
>
>> Please check
>> C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
>> for errors
>> CPack Error: Problem compressing the directory
>> CPack Error: Error when generating package: Boost
>> NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
>> 2.6\bin\cpack.exe"' : return code '0x1'
>> Stop.
>>
>> One clue might be that the CMake setup shows the UNZIP value as
>> "C:/bgd/util/unzip.exe" That's almost certainly not the unzip program
>> CMake expects. Perhaps I need to install cygwin zip/unzip programs?
>> I'll see if they've got anything by that name.
>>
> I don't think zip should affect nsis.
>
>
> What is in here:
> C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log

I zipped up the log together with project.nsi and one other file.

See http://mysite.verizon.net/beman/NSIS.zip

HTH,

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Bill Hoffman

Beman Dawes wrote:


Please check 
C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
for errors
CPack Error: Problem compressing the directory
CPack Error: Error when generating package: Boost
NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
2.6\bin\cpack.exe"' : return code '0x1'
Stop.

One clue might be that the CMake setup shows the UNZIP value as
"C:/bgd/util/unzip.exe" That's almost certainly not the unzip program
CMake expects. Perhaps I need to install cygwin zip/unzip programs?
I'll see if they've got anything by that name.


I don't think zip should affect nsis.


What is in here:
C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log


-Bill
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Doug Gregor
On Tue, May 12, 2009 at 1:37 PM, Brad King  wrote:
> Doug Gregor wrote:
>>
>> On Tue, May 12, 2009 at 1:02 PM, Beman Dawes  wrote:
>>>
>>> I first tried to use the VC++ IDE compiler. The Solution file is so
>>> large it is impossibly slow to load and unload. A non-starter. Bill or
>>> Brad had warned about that, so no surprise, and I just moved on to the
>>> command line compiler. That's what I prefer for these canned builds
>>> anyhow.
>>
>> Ugh. We'll still have to see if we can find a way around this.
>
> This is due to the large number of separate test executables.
> Combining tests into test drivers will solve this (along with
> reducing disk usage, total link time, etc.).

Beman, did you enable testing?

Even without all of the tests, Boost still has a huge number of targets in it.

  - Doug
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Brad King

Doug Gregor wrote:

On Tue, May 12, 2009 at 1:02 PM, Beman Dawes  wrote:

I first tried to use the VC++ IDE compiler. The Solution file is so
large it is impossibly slow to load and unload. A non-starter. Bill or
Brad had warned about that, so no surprise, and I just moved on to the
command line compiler. That's what I prefer for these canned builds
anyhow.


Ugh. We'll still have to see if we can find a way around this.


This is due to the large number of separate test executables.
Combining tests into test drivers will solve this (along with
reducing disk usage, total link time, etc.).

-Brad
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Doug Gregor
On Tue, May 12, 2009 at 1:27 PM, Beman Dawes  wrote:
> On Tue, May 12, 2009 at 4:09 PM, Doug Gregor  wrote:
>> On Tue, May 12, 2009 at 1:02 PM, Beman Dawes  wrote:
> 
>> I suspect it's just:
>>
>>  nmake modularize
>>
>> then
>>
>>  nmake package
>
> Yeah, that's what I did. Died on bcp again, so I removed the bcp
> checkmark, did configure/generate again, and was back in business.
>
> The various nmake runs went much faster - a good sign.
>
> Got down to:
>
> ...
> Run CPack packaging tool...
> CPack: Create package using NSIS
> CPack: Install projects
> CPack: - Run preinstall target for: Boost
> CPack: - Install project: Boost
> CPack: -   Install component: Unspecified
> CPack: -   Install component: accumulators_headers
> CPack: -   Install component: algorithm_headers
> ...
> CPack: -   Install component: variant_headers
> CPack: -   Install component: wave_headers
> CPack: -   Install component: wave_mt_shared
> CPack: -   Install component: xpressive_headers
> CPack: Compress package
> CPack Error: Problem running NSIS command: "C:/Program Files
> (x86)/NSIS/makensis.exe" "C:/boost/rele
> ase-cmake-build/_CPack_Packages/win32/NSIS/project.nsi"
> Please check 
> C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
> for errors
> CPack Error: Problem compressing the directory
> CPack Error: Error when generating package: Boost
> NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
> 2.6\bin\cpack.exe"' : return code '0x1'
> Stop.
>
> One clue might be that the CMake setup shows the UNZIP value as
> "C:/bgd/util/unzip.exe" That's almost certainly not the unzip program
> CMake expects. Perhaps I need to install cygwin zip/unzip programs?
> I'll see if they've got anything by that name.

Ugh. It's probably not zip/unzip per se. More likely, NSIS didn't like
the project file it was given. If you could post the contents of
C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log,
it would help us debug.

I have *got* to get my hands on a Windows machine.

  - Doug
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Beman Dawes
On Tue, May 12, 2009 at 4:09 PM, Doug Gregor  wrote:
> On Tue, May 12, 2009 at 1:02 PM, Beman Dawes  wrote:

> I suspect it's just:
>
>  nmake modularize
>
> then
>
>  nmake package

Yeah, that's what I did. Died on bcp again, so I removed the bcp
checkmark, did configure/generate again, and was back in business.

The various nmake runs went much faster - a good sign.

Got down to:

...
Run CPack packaging tool...
CPack: Create package using NSIS
CPack: Install projects
CPack: - Run preinstall target for: Boost
CPack: - Install project: Boost
CPack: -   Install component: Unspecified
CPack: -   Install component: accumulators_headers
CPack: -   Install component: algorithm_headers
...
CPack: -   Install component: variant_headers
CPack: -   Install component: wave_headers
CPack: -   Install component: wave_mt_shared
CPack: -   Install component: xpressive_headers
CPack: Compress package
CPack Error: Problem running NSIS command: "C:/Program Files
(x86)/NSIS/makensis.exe" "C:/boost/rele
ase-cmake-build/_CPack_Packages/win32/NSIS/project.nsi"
Please check 
C:/boost/release-cmake-build/_CPack_Packages/win32/NSIS/NSISOutput.log
for errors
CPack Error: Problem compressing the directory
CPack Error: Error when generating package: Boost
NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
2.6\bin\cpack.exe"' : return code '0x1'
Stop.

One clue might be that the CMake setup shows the UNZIP value as
"C:/bgd/util/unzip.exe" That's almost certainly not the unzip program
CMake expects. Perhaps I need to install cygwin zip/unzip programs?
I'll see if they've got anything by that name.

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Doug Gregor
On Tue, May 12, 2009 at 1:02 PM, Beman Dawes  wrote:
> I first tried to use the VC++ IDE compiler. The Solution file is so
> large it is impossibly slow to load and unload. A non-starter. Bill or
> Brad had warned about that, so no surprise, and I just moved on to the
> command line compiler. That's what I prefer for these canned builds
> anyhow.

Ugh. We'll still have to see if we can find a way around this.

> The files identified the build as 1_38, so it looks like yet another
> version number needs updating between releases. (I was running on
> branches/release).

We'll just parse the version number from boost/version.hpp; we don't
want to have yet another version number of worry about.

> After [100%], there were error messages:
>
> Linking CXX executable ..\..\bin\bcp.exe
> LINK : fatal error LNK1104: cannot open file 
> 'boost_system-mt-shared-debug.lib'
> LINK Pass 1 failed. with 2
> NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
> 2.6\bin\cmake.exe"' : return code '0xf
> fff'
> Stop.
> NMAKE : fatal error U1077: '"C:\Program Files (x86)\Microsoft Visual
> Studio 9.0\VC\BIN\nmake.exe"' :
>  return code '0x2'
> Stop.
> NMAKE : fatal error U1077: '"C:\Program Files (x86)\Microsoft Visual
> Studio 9.0\VC\BIN\nmake.exe"' :
>  return code '0x2'
> Stop.
>
> I probably shouldn't have tried to build bcp; I'm still getting used
> to the configure options.

Interesting; I'll look into this later. The CMake rules for the
"tools" subdirectory are a bit ugly now, but clearly something is
going wrong here.

> Anyhow, not a bad start for the first try. What do I do to create an
> installer? Is there a set of nmake commands?

I suspect it's just:

  nmake modularize

then

  nmake package

  - Doug
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


Re: [Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread Beman Dawes
On Tue, May 12, 2009 at 9:16 AM, troy d. straszheim  wrote:
> I've been working hard on getting some proper docs together.  Whats done is
> here:
>
>  http://www.resophonic.com/boost_cmake/index.html
>
> Not quite everything is off the wiki just yet.   Bug reports welcome, help
> is more welcome.

Nice, readable, docs! Great start!

In the Windows section,

* Use the Browse... button to point CMake at the Boost source
code in $BOOST\src.
* Use the second Browse... button to select the directory
where Boost will build binaries, $BOOST\build.
* CMake will ask you what kind of project files or make files
to build. If you’re using Microsoft Visual Studio, select the
appropriate version to generate project files. Otherwise, you can use
Borland’s make files, generate NMake files, etc.
* Click Configure a first time to configure Boost, which will
search for various libraries on your system and prepare the build.
* You will then be given the opportunity to tune build options
in the CMake GUI (see also [wiki:CMakeBuildConfiguration]. These
options will affect what libraries are built and how. They will
initially appear red. Click Configure again when you are done editing
them.
* Finally, click OK to generate project files.

The third bullet item actually happens after the 4th bullet item.

I first tried to use the VC++ IDE compiler. The Solution file is so
large it is impossibly slow to load and unload. A non-starter. Bill or
Brad had warned about that, so no surprise, and I just moved on to the
command line compiler. That's what I prefer for these canned builds
anyhow.

That is specified as "nmake" rather than by something descriptive like
"Microsoft command line tools". I'd really prefer not to ever know of
the existence of nmake. That is where bjam shines. So I'm looking
forward to a wrapper that hides all make tools behind a common
interface.

I typed "nmake", hoping that might be all that was required, and
compiles started to run, and .lib and .exp files started to appear in
the lib sub-directory while .dll and .exe files started to appear in
the bin sub-directory.

The files identified the build as 1_38, so it looks like yet another
version number needs updating between releases. (I was running on
branches/release).

After [100%], there were error messages:

Linking CXX executable ..\..\bin\bcp.exe
LINK : fatal error LNK1104: cannot open file 'boost_system-mt-shared-debug.lib'
LINK Pass 1 failed. with 2
NMAKE : fatal error U1077: '"C:\Program Files (x86)\CMake
2.6\bin\cmake.exe"' : return code '0xf
fff'
Stop.
NMAKE : fatal error U1077: '"C:\Program Files (x86)\Microsoft Visual
Studio 9.0\VC\BIN\nmake.exe"' :
 return code '0x2'
Stop.
NMAKE : fatal error U1077: '"C:\Program Files (x86)\Microsoft Visual
Studio 9.0\VC\BIN\nmake.exe"' :
 return code '0x2'
Stop.

I probably shouldn't have tried to build bcp; I'm still getting used
to the configure options.

Anyhow, not a bad start for the first try. What do I do to create an
installer? Is there a set of nmake commands?

Thanks,

--Beman
___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake


[Boost-cmake] Wiki to disappear: docs in progress

2009-05-12 Thread troy d. straszheim
I've been working hard on getting some proper docs together.  Whats done 
is here:


  http://www.resophonic.com/boost_cmake/index.html

Not quite everything is off the wiki just yet.   Bug reports welcome, 
help is more welcome.  If you're good with restructuredtext/sphinx/git, 
you can clone this stuff here:


  git://sodium.resophonic.com/boost_cookbook

they're on the boost_cmake_docs branch.  That is,

  git clone git://sodium.resophonic.com/boost_cookbook
  cd boost_cookbook
  checkout -b my_doctweaks_branch boost_cmake_docs
  emacs source/*.rst

alternately, you can just click the 'show source' link, get that text 
into an editor, hack on it, and mail it to me.


-t
@@ -56,7 +56,7 @@
 #
 # For libraries that have regression tests, and when testing is
-# enabled globally by the BUILD_TESTING option, this macro also
+# enabled globally by the BUILD_REGRESSION_TESTS option, this macro also
 # defines the TEST_BOOST_LIBNAME option (defaults to ON). When ON, the
 # generated makefiles/project files will contain regression tests for

___
Boost-cmake mailing list
Boost-cmake@lists.boost.org
http://lists.boost.org/mailman/listinfo.cgi/boost-cmake